| bootstrap_samples | R Documentation |
This function extracts the indices used to bootstrap the data for each replicate. This is helpful when doing some additional analysis that requires knowledge of the exact bootstrap samples used.
bootstrap_samples(model)
model |
A model of class bolasso. |
A named list of length equal to the number of bootstrap replicates that contains the corresponding indices used to subsample the data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.